FUNCTION cross_corr, template, spec, corr_size
;** IDL function to cross correlate one spectrum with a template
;** "template" and "spec" must be the same length (even number). 
;** Return a reduced size of array centred around zero shift. 
;** Written ages ago by Ivan Baldry. 

;** take conjugate of Fourier transform of rebinned template spectrum
fft_t = fft(template,-1)
fft_t = conj(fft_t)

;** take Fourier transform of spectrum
fft_spec = fft(spec,-1)

;** multiply by conj. of Fourier transform of t_plate spectrum
fft_spec = fft_spec * fft_t

;** take real part of inverse FFT for cross correlation. 
inv_fft = fft(fft_spec,1)
cr_c = real_part(inv_fft)

;** move 'zero shift' to n_shift position. 
n_shift = n_elements(cr_c)/2
cr_c = shift(cr_c,n_shift)

;** create output array: length = 2*corr_size+1 (odd number of elements)
cr_corr = cr_c[n_shift-corr_size:n_shift+corr_size]

return, cr_corr

end
