FUNCTION find_highest_peaks, ccinfo, num=num
;** Find highest peaks across the cross-correlation functions. 
;** Note that in this routine peaks.template and template_list refers
;** to the index within the ccinfo structure and NOT the template number that
;** is finally assigned. 
;** Written by Ivan Baldry. 
;** Reference: Baldry et al. 2014, MNRAS, 441, 2440

template_list  = -1
indexes_list   = long(-1)
redshift_list  = -1.
crosscorr_list = 0.

;** first extract all peaks in normalised cross correlation value
;** across all templates
for t_i=0, n_elements(ccinfo)-1 do begin
;** cross correlation values of peaks in allowed range (not a peak = 0)
  testvals = ccinfo[t_i].crosscorr * ((ccinfo[t_i].mask_info and 5) EQ 5)
;** save only certain peaks
  use = where(testvals GE 1., count)
  if count GE 1 then begin
    template_list  = [template_list, intarr(count) + t_i]
    indexes_list   = [indexes_list, use]
    redshift_list  = [redshift_list, ccinfo[t_i].shifts[use]]
    crosscorr_list = [crosscorr_list, testvals[use]]
  endif
endfor

if keyword_set(num) EQ 0 then num=4

peaks = replicate({peaks_v1, template: 0, shift_index: long(0),$
  redshift: 0.0, crosscorr: 0.0}, num)

for i=0, num-1 do begin
;** find highest peak remaining
  maxcorr = max(crosscorr_list, pt)
  peaks[i].template    = template_list[pt]
  peaks[i].shift_index = indexes_list[pt]
  peaks[i].redshift    = redshift_list[pt]
  peaks[i].crosscorr   = maxcorr

;** exclude +- 600 km/s in next search
  zrange  = (1. + peaks[i].redshift) * (1. + [-0.002,0.002]) - 1.
  use = where(criteria_between(redshift_list, zrange))
  crosscorr_list[use] = -1.
endfor

return, peaks

end
