FUNCTION fit_and_filter, lambda, spec, st_lambda, end_lambda, ndegree=ndegree,$
  os1=os1, os2=os2, use_fit=use_fit, use_nan=use_nan, count_nan=count_nan, $
  spec_smooth=spec_smooth, spec_fit=spec_fit, silent=silent
;** Robustly high-pass filter a spectrum and filter ends. 
;** Reference: Baldry et al. 2014, MNRAS, 441, 2440
;** Written by Ivan Baldry. 

if keyword_set(ndegree) EQ 0 then ndegree = 4

;** Offsets for filters.
if keyword_set(os1) EQ 0 then os1 = 100.
if keyword_set(os2) EQ 0 then os2 = 300.

;** Set up region to use for fitting between st_lambda and end_lambda.
;** Also only use finite values. 
c_fit_region = criteria_between(lambda, [st_lambda, end_lambda])
c_finite = finite(spec)
use_fit = where(c_fit_region and c_finite)
use_nan = where(c_finite EQ 0, count_nan)

;** First fit ndegree polynomial and subtract fit. 
;** This uses an iterative rejection routine to remove outliers. 
res = poly_reject(lambda[use_fit], spec[use_fit], ndegree, low=3.5, high=3.5, $
  niter=15, num_reject=num_reject, reject_pts=reject_pts, pts=pts,$
  silent=silent)
spec_fit = poly_calc(res, lambda)
spec_out = spec - spec_fit
if count_nan GE 1 then spec_out[use_nan] = 0.0

;** Create smooth version of resulting spectrum - using median filtering --
;** and then a trapezium smoothing effectively - 
;** and then subtract smoothed spectrum. 
spec_smooth = spec_out
;;if num_reject GE 1 then spec_smooth[use_fit[reject_pts]] = 0.0
spec_smooth = med_smooth(spec_smooth, 51, 121)
spec_smooth = smooth(spec_smooth, 21, /edge_truncate)
spec_out = spec_out - spec_smooth

;** Set end points smoothly to zero between st_lambda+os2 and st_lambda+os1
use = where(criteria_between(lambda, [st_lambda+os1,st_lambda+os2]), count)
if count GE 2 then spec_out[use] = spec_out[use] * cosine_filter(count)
use = where(lambda LE st_lambda+os1, count_st_lambda)
if count_st_lambda GE 1 then spec_out[use] = 0.0 else print, $
  '% FIT_AND_FILTER: Low zero point', min(lambda), ' taper to', $
  (st_lambda+os2) > min(lambda), ' AA', format='(a,f8.2,a,f8.2,a)'

;** Set end points smoothly to zero between end_lambda-os2 and end_lambda-os1
use = where(criteria_between(lambda, [end_lambda-os2,end_lambda-os1]), count)
if count GE 2 then spec_out[use] = spec_out[use] * cosine_filter(count, /reverse)
use = where(lambda GT end_lambda-os1, count_end_lambda)
if count_end_lambda GE 1 then spec_out[use] = 0.0 else print, $
  '% FIT_AND_FILTER: High zero point', max(lambda), ' taper to', $
  (end_lambda-os2) < max(lambda), ' AA', format='(a,f8.2,a,f8.2,a)'

;** Finally reset bad regions again to zero. 
if count_nan GE 1 then spec_out[use_nan] = 0.0

return, spec_out

end
