FUNCTION median_adjust, spec, width
;** Perform median filter with edge adjustment on a vector spectrum. 
;** IDL median does not run a median filter over the edge points.
;** This routine gives the edge points the same value using a median
;** value over those points plus two more points. 
;** Written by Ivan Baldry. 

num = n_elements(spec) ;** example num=1000

outspec = median(spec, width, /even)  ;** example width=51

;** use a filter of half the width for the edge points
i1 = (width/2 - 1) > 0   ;** example i1=24
i2 = (width/2 + 1)       ;** example i2=26

;** Replace edge points not covered by idl median.pro 
;** example 0:24    becomes median of 0:26    (27 points)
outspec[0:i1]           = median(spec[0:i2], /even)   
;** example 975:999 becomes median of 973:999 (27 points)
outspec[num-1-i1:num-1] = median(spec[num-1-i2:num-1], /even)

return, outspec

end
