FUNCTION normalise_meandev, spec, clipvalue=clipvalue, use=use,$
  percentvalue=percentvalue, mean_deviation=mean_deviation
;** Normalise a spectrum by dividing by mean absolute deviation.
;** Iterate for clipping if clipvalue keyword is set. 
;** Written by Ivan Baldry. 

spec_out = spec

;** If use keyword for indexes is not defined then 
;** set indexes to use for calculation of mean absolute deviation
;** default is to reject largest 5 percent
if keyword_set(use) EQ 0 then begin
  if keyword_set(percentvalue) EQ 0 then percentvalue = 0.95
  c_finite = finite(spec_out)
  testval = percentiles( abs(spec_out[where(c_finite)]), percentvalue )
  use = where( c_finite and (abs(spec_out) LE testval) )
endif

if keyword_set(clipvalue) then begin
;** Iterate mean deviation clipping each time until convergence within
;** a tolerance of 0.01.
  cliptest = clipvalue+0.01
  test_dev = 1
  while (test_dev EQ 1) do begin
    mean_deviation = mean( abs(spec_out[use]) )
    if max(abs(spec_out)) GT (cliptest*mean_deviation) then test_dev = 1 else test_dev = 0
    spec_out = spec_out > (-clipvalue*mean_deviation) < (clipvalue*mean_deviation)
  endwhile
endif else begin
  mean_deviation = mean( abs(spec_out[use]) )
endelse

;** normalise
spec_out = spec_out / mean_deviation

return, spec_out

end
