FUNCTION poly_reject, x, y, degree, high_sigma=high_sigma, $
  low_sigma=low_sigma, niterate=niterate, pts=pts, silent=silent, $
  sd=sd_use, double=double, yfit=yfit, reject_pts=reject_pts, $
  num_reject=num_reject
;** Polynomial fitting with sigma rejection, return coefficients.
;** Written by Ivan Baldry. 

if keyword_set(high_sigma) EQ 0 then high_sigma = 10.0
if keyword_set(low_sigma) EQ 0 then low_sigma = 10.0
if n_elements(niterate) EQ 0 then niterate = 3

;** Initial setting - sigma=0 everywhere.
sigmas = 0.0 * y

i = 1  &  iteration_finished = 0

while (iteration_finished EQ 0) do begin
  pts = where(sigmas LT high_sigma AND sigmas GT -low_sigma)

  res = poly_fit(x[pts], y[pts], degree, yfit=yfit, double=double)
  sd_use = stddev( y[pts] - yfit )
  sigmas[pts] = (y[pts] - yfit) / sd_use

;** test if finished iteration and print if required
  if (total(sigmas[pts] GT high_sigma OR sigmas[pts] LT -low_sigma) EQ 0) OR $
    (i EQ niterate) then begin
    num_reject = n_elements(x) - n_elements(pts)
    if keyword_set(silent) EQ 0 then $
       print, '% POLY_REJECT: iteration=', i, '/', niterate, '  : rejected=', $
       num_reject, form='(a,i4,a,i4,a,i6)'
    iteration_finished = 1
  endif
  i = i + 1

endwhile

reject_pts = where(sigmas GE high_sigma or sigmas LE -low_sigma)

yfit = poly_calc(res, x)

return, res

end
