FUNCTION rebin_template_data, log_lambda, template_numbers, file=file,$
  num_templates=num_templates
;** Read in and rebin template data to new scale. 
;** Select templates to use. Wavelengths are in *vacuum* as per SDSS. 
;** Written by Ivan Baldry.
;** Reference: Baldry et al. 2014, MNRAS, 441, 2440

if keyword_set(file) EQ 0 then file = 'data/filtered-templates.fits'
print, '% REBIN_TEMPLATE_DATA: Reading ', file
tdata = mrdfits(file,1)

num_templates = n_elements(tdata)
num_lambda_new = n_elements(log_lambda)

outdata = replicate({tdata_rebin_v3, template_num: -1, file: '', $
  redshift: 0.0, spec: dblarr(num_lambda_new)}, num_templates)
outdata.template_num = tdata.template_num
outdata.file         = tdata.file
outdata.redshift     = tdata.redshift

for i=0, num_templates-1 do if tdata[i].log_lambda[0] GT 0. then begin
  num = tdata[i].num_points
  specrebin = interpol(tdata[i].spec[0:num-1], tdata[i].log_lambda[0:num-1], $
    log_lambda)
;** just to be sure, set outside scale points to zero
  use = where(log_lambda LT tdata[i].log_lambda[0] or $
              log_lambda GT tdata[i].log_lambda[num-1], count)
  if count GE 1 then specrebin[use] = 0.0
  outdata[i].spec = specrebin  

endif

;** set default template numbers to use: 20 stellar and 8 galaxy templates. 
if keyword_set(template_numbers) EQ 0 then $
  template_numbers = [2+indgen(13),16+indgen(7),40+indgen(8)]

;** reduce to selected templates.
mindx = match_values(outdata.template_num, template_numbers)
outdata = outdata[where(mindx GE 0, num_templates)]
print, '% REBIN_TEMPLATE_DATA: Using templates:', outdata.template_num

return, outdata

end
