FUNCTION vacuum_from_air, AIR, convert_lookup=convert_lookup
;** Convert from vacuum wavelengths to air wavelengths by interpolating
;** from a lookup table.
;** Equation from SDSS web page 
;** http://www.sdss.org/dr7/products/spectra/vacwavelength.html. 
;** Reference to Morton (1991, ApJS, 77, 119). 
;** Written by Ivan Baldry.

VAC_lookup = dindgen(8000) + 3500.
convert_lookup = $
  (1.0 + 2.735182E-4 + 131.4182 / VAC_lookup^2 + 2.76249E8 / VAC_lookup^4)
AIR_lookup = VAC_lookup / convert_lookup

convert = interpol(convert_lookup, AIR_lookup, AIR)

VAC = AIR * convert

return, VAC

end
